@@ -1,26 +1,25 @@
 /*
  * Copyright 2011 Red Hat, Inc. and/or its affiliates.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not
- * use this file except in compliance with the License. You may obtain a copy of
- * the License at
- * 
- * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations under
- * the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.drools.workbench.screens.guided.dtable.client.widget.table;
 
-import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Optional;
 import java.util.Set;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
@@ -29,15 +28,10 @@ import javax.inject.Inject;
 import com.ait.lienzo.client.core.types.Point2D;
 import com.google.gwt.event.shared.HandlerRegistration;
 import com.google.gwt.user.client.Command;
-import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTablePinnedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshActionsPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshAttributesPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshConditionsPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMetaDataPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.keyboard.DeleteAndEditCell;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.keyboard.DeleteCell;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.keyboard.EditCell;
@@ -67,21 +61,27 @@ import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperati
 import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.KeyboardOperationMoveUp;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.GridLayer;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.TransformMediator;
-import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 
 @Dependent
 public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTableModellerView.Presenter {
 
     private final GuidedDecisionTableModellerView view;
+
     private final ManagedInstance<GuidedDecisionTableView.Presenter> dtPresenterProvider;
+
     private final Event<RadarMenuBuilder.UpdateRadarEvent> updateRadarEvent;
+
     private final Event<DecisionTablePinnedEvent> pinnedEvent;
+
     private final ColumnHeaderPopOver columnHeaderPopOver;
+
     private final ManagedInstance<NewGuidedDecisionTableColumnWizard> wizardManagedInstance;
 
     private GuidedDecisionTableView.Presenter activeDecisionTable = null;
-    private Set<GuidedDecisionTableView.Presenter> availableDecisionTables = new HashSet<GuidedDecisionTableView.Presenter>();
+
+    private Set<GuidedDecisionTableView.Presenter> availableDecisionTables = new HashSet<>();
+
     private Set<HandlerRegistration> handlerRegistrations = new HashSet<>();
 
     @Inject
@@ -143,14 +143,14 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
     @Override
     public void releaseDecisionTables() {
         //Release objects created manually with BeanManager
-        availableDecisionTables.stream().forEach(GuidedDecisionTableView.Presenter::onClose);
+        availableDecisionTables.forEach(GuidedDecisionTableView.Presenter::onClose);
         availableDecisionTables.clear();
     }
 
     @Override
     public void releaseHandlerRegistrations() {
         //Release HandlerRegistrations
-        handlerRegistrations.stream().forEach(HandlerRegistration::removeHandler);
+        handlerRegistrations.forEach(HandlerRegistration::removeHandler);
         handlerRegistrations.clear();
     }
 
@@ -229,12 +229,6 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
     @Override
     public void removeDecisionTable(final GuidedDecisionTableView.Presenter dtPresenter) {
         final Command afterRemovalCommand = () -> {
-            view.setEnableColumnCreation(false);
-            view.refreshAttributeWidget(Collections.emptyList());
-            view.refreshMetaDataWidget(Collections.emptyList());
-            view.refreshConditionsWidget(Collections.emptyList());
-            view.refreshActionsWidget(Collections.emptyList());
-            view.refreshColumnsNote(false);
 
             availableDecisionTables.remove(dtPresenter);
 
@@ -261,20 +255,8 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
     }
 
     @Override
-    public void onLockStatusUpdated(final GuidedDecisionTableView.Presenter dtPresenter) {
-        if (dtPresenter == null) {
-            return;
-        }
-
-        //Update Definitions Panel if active Decision Table's lock has changed
-        if (dtPresenter.equals(getActiveDecisionTable())) {
-            refreshDefinitionsPanel(dtPresenter);
-        }
-    }
-
-    @Override
-    public GuidedDecisionTableView.Presenter getActiveDecisionTable() {
-        return activeDecisionTable;
+    public Optional<GuidedDecisionTableView.Presenter> getActiveDecisionTable() {
+        return Optional.ofNullable(activeDecisionTable);
     }
 
     @Override
@@ -289,11 +271,11 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
 
     @Override
     public boolean isActiveDecisionTableEditable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = getActiveDecisionTable();
-        if (dtPresenter == null) {
-            return false;
+        final Optional<GuidedDecisionTableView.Presenter> dtPresenter = getActiveDecisionTable();
+        if (dtPresenter.isPresent()) {
+            return dtPresenter.get().getAccess().isEditable();
         }
-        return dtPresenter.getAccess().isEditable();
+        return false;
     }
 
     @Override
@@ -306,15 +288,6 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         view.setZoom(zoom);
     }
 
-    @Override
-    public void onInsertColumn() {
-        final GuidedDecisionTableView.Presenter dtPresenter = getActiveDecisionTable();
-        if (dtPresenter == null) {
-            return;
-        }
-        view.onInsertColumn();
-    }
-
     @Override
     public void enterPinnedMode(final GridWidget gridWidget,
                                 final Command onStartCommand) {
@@ -364,27 +337,24 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
     public void onDecisionTableSelected(final @Observes DecisionTableSelectedEvent event) {
         final Optional<GuidedDecisionTableView.Presenter> dtPresenter = event.getPresenter();
         if (!dtPresenter.isPresent()) {
+            activeDecisionTable = null;
             return;
         }
         final GuidedDecisionTableView.Presenter presenter = dtPresenter.get();
         if (!isDecisionTableAvailable(presenter)) {
             return;
         }
-        if (presenter.equals(getActiveDecisionTable())) {
-            return;
+        final Optional<GuidedDecisionTableView.Presenter> activeDecisionTable = getActiveDecisionTable();
+        if (activeDecisionTable.isPresent()) {
+            if (presenter.equals(activeDecisionTable.get())) {
+                return;
+            }
         }
+
         doDecisionTableSelected(presenter);
     }
 
-    @Override
-    public void openNewGuidedDecisionTableColumnWizard() {
-        final NewGuidedDecisionTableColumnWizard wizard = wizardManagedInstance.get();
-
-        wizard.init(activeDecisionTable);
-        wizard.start();
-    }
-
-    private void doDecisionTableSelected(final GuidedDecisionTableView.Presenter dtPresenter) {
+    void doDecisionTableSelected(final GuidedDecisionTableView.Presenter dtPresenter) {
         //Store selected decision table
         activeDecisionTable = dtPresenter;
 
@@ -395,63 +365,12 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
             }
         }
 
-        //Update view with selected decision table detail
-        final GuidedDecisionTable52 model = dtPresenter.getModel();
-        dtPresenter.getPackageParentRuleNames(new ParameterizedCommand<Collection<String>>() {
-            @Override
-            public void execute(Collection<String> availableParentRuleNames) {
-                view.refreshRuleInheritance(model.getParentName(),
-                                            availableParentRuleNames);
-            }
-        });
-        refreshDefinitionsPanel(dtPresenter);
-
-        //Delegate highlighting of selected decision table to ISelectionManager
         view.select(dtPresenter.getView());
 
         //If the Layer is "pinned" flip to the selected Decision Table
         if (isGridPinned()) {
             view.getGridLayerView().flipToGridWidget(dtPresenter.getView());
         }
-
-        handlePermissions(dtPresenter);
-    }
-
-    void handlePermissions(final GuidedDecisionTableView.Presenter dtPresenter) {
-        if (dtPresenter.hasEditableColumns()) {
-            view.enableColumnOperationsMenu();
-        }
-    }
-
-    void refreshDefinitionsPanel(final GuidedDecisionTableView.Presenter dtPresenter) {
-        final GuidedDecisionTable52 model = dtPresenter.getModel();
-
-        view.setEnableColumnCreation(isColumnCreationEnabled(dtPresenter));
-        view.refreshAttributeWidget(model.getAttributeCols());
-        view.refreshMetaDataWidget(model.getMetadataCols());
-        view.refreshConditionsWidget(model.getConditions());
-        view.refreshActionsWidget(model.getActionCols());
-        view.refreshColumnsNote(dtPresenter.hasColumnDefinitions());
-    }
-
-    boolean isColumnCreationEnabled(final GuidedDecisionTableView.Presenter dtPresenter) {
-
-        final boolean decisionTableIsEditable = !dtPresenter.isReadOnly();
-        final boolean decisionTableHasEditableColumns = dtPresenter.hasEditableColumns();
-
-        return decisionTableHasEditableColumns && decisionTableIsEditable;
-    }
-
-    @Override
-    public boolean isColumnCreationEnabledToActiveDecisionTable() {
-
-        final Optional<GuidedDecisionTableView.Presenter> decisionTable = Optional.ofNullable(getActiveDecisionTable());
-
-        if (!decisionTable.isPresent()) {
-            return false;
-        }
-
-        return isColumnCreationEnabled(decisionTable.get());
     }
 
     @Override
@@ -462,46 +381,6 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
         view.selectLinkedColumn(event.getColumn());
     }
 
-    @Override
-    public void onRefreshAttributesPanelEvent(final @Observes RefreshAttributesPanelEvent event) {
-        refreshPanel(event.getPresenter(),
-                     event.getColumns(),
-                     view::refreshAttributeWidget);
-    }
-
-    @Override
-    public void onRefreshMetaDataPanelEvent(final @Observes RefreshMetaDataPanelEvent event) {
-        refreshPanel(event.getPresenter(),
-                     event.getColumns(),
-                     view::refreshMetaDataWidget);
-    }
-
-    @Override
-    public void onRefreshConditionsPanelEvent(final @Observes RefreshConditionsPanelEvent event) {
-        refreshPanel(event.getPresenter(),
-                     event.getColumns(),
-                     view::refreshConditionsWidget);
-    }
-
-    @Override
-    public void onRefreshActionsPanelEvent(final @Observes RefreshActionsPanelEvent event) {
-        refreshPanel(event.getPresenter(),
-                     event.getColumns(),
-                     view::refreshActionsWidget);
-    }
-
-    private <C> void refreshPanel(final GuidedDecisionTableView.Presenter dtPresenter,
-                                  final List<C> columns,
-                                  final ParameterizedCommand<List<C>> command) {
-        if (dtPresenter == null) {
-            return;
-        }
-        if (!isDecisionTableAvailable(dtPresenter)) {
-            return;
-        }
-        command.execute(columns);
-    }
-
     @Override
     public void updateRadar() {
         updateRadarEvent.fire(new RadarMenuBuilder.UpdateRadarEvent(this));
@@ -511,6 +390,7 @@ public class GuidedDecisionTableModellerPresenter implements GuidedDecisionTable
     public void onViewPinned(final boolean isPinned) {
         pinnedEvent.fire(new DecisionTablePinnedEvent(this,
                                                       isPinned));
+        view.setPinnedModeIndicatorVisibility(isPinned);
     }
 
     @Override
