@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,9 +17,12 @@
 package org.drools.workbench.screens.guided.dtable.client.wizard.column.pages;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.function.Consumer;
+import java.util.stream.Collectors;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -75,13 +78,29 @@ public class OperatorPage extends BaseDecisionTableColumnPage<ConditionColumnPlu
 
         setupWarningMessages();
         setupOperator();
+        setupCurrentField();
     }
 
-    private void setupOperator() {
+    void setupCurrentField() {
+        view.setCurrentField(currentField());
+        view.currentFieldToggle(hasFactField());
+    }
+
+    String currentField() {
+
+        final List<String> parts = Arrays.asList(plugin().getBinding(), plugin().getFactField());
+
+        return parts
+                .stream()
+                .filter(part -> !nil(part))
+                .collect(Collectors.joining(" : "));
+    }
+
+    void setupOperator() {
         operatorDropdown(dropdown -> view.setupOperator(dropdown));
     }
 
-    private void setupWarningMessages() {
+    void setupWarningMessages() {
         if (isConstraintValuePredicate()) {
             view.showPredicateWarning();
         } else {
@@ -112,13 +131,17 @@ public class OperatorPage extends BaseDecisionTableColumnPage<ConditionColumnPlu
     }
 
     void operatorDropdown(final Consumer<IsWidget> widgetSupplier) {
-        if (hasFactField()) {
+        if (canOperatorBeSet()) {
             cepOperatorsDropdown(widgetSupplier);
         } else {
             emptyOperatorsDropdown(widgetSupplier);
         }
     }
 
+    boolean canOperatorBeSet() {
+        return hasFactField() && !isConstraintValuePredicate();
+    }
+
     boolean isConstraintValuePredicate() {
         return plugin().constraintValue() == BaseSingleFieldConstraint.TYPE_PREDICATE;
     }
@@ -218,5 +241,9 @@ public class OperatorPage extends BaseDecisionTableColumnPage<ConditionColumnPlu
         void showOperatorWarning();
 
         void hideOperatorWarning();
+
+        void setCurrentField(String currentField);
+
+        void currentFieldToggle(final boolean isVisible);
     }
 }
