@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,8 +19,6 @@ package org.drools.workbench.screens.guided.dtable.client.widget.table.model.syn
 import java.util.Collections;
 import java.util.List;
 
-import org.drools.workbench.models.datamodel.oracle.DataType;
-import org.drools.workbench.models.datamodel.oracle.ModelField;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
 import org.drools.workbench.models.datamodel.workitems.PortableWorkDefinition;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionWorkItemCol52;
@@ -30,9 +28,11 @@ import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.BaseMultipleDOMElementUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.BooleanUiColumn;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.junit.Before;
 import org.junit.Test;
+import org.kie.soup.project.datamodel.oracle.DataType;
+import org.kie.soup.project.datamodel.oracle.ModelField;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
@@ -48,7 +48,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     private static final String WORK_ITEM_NAME = "WorkItemDefinition";
 
     @Before
-    public void setupWorkItemExecution() throws ModelSynchronizer.MoveColumnVetoException {
+    public void setupWorkItemExecution() throws VetoException {
         final ActionWorkItemCol52 column = new ActionWorkItemCol52();
         final PortableWorkDefinition pwd = new PortableWorkDefinition();
         pwd.setName(WORK_ITEM_NAME);
@@ -74,7 +74,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testAppend() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppend() throws VetoException {
         final ActionWorkItemSetFieldCol52 column = new ActionWorkItemSetFieldCol52();
         column.setWorkItemName(WORK_ITEM_NAME);
         column.setHeader("col1");
@@ -92,7 +92,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testAppendMultipleColumns() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppendMultipleColumns() throws VetoException {
         final ActionWorkItemSetFieldCol52 column1 = new ActionWorkItemSetFieldCol52();
         column1.setWorkItemName(WORK_ITEM_NAME);
         column1.setHeader("col1");
@@ -123,7 +123,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testUpdate() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate() throws VetoException {
         final ActionWorkItemSetFieldCol52 column = spy(new ActionWorkItemSetFieldCol52());
         column.setWorkItemName(WORK_ITEM_NAME);
         column.setHeader("col1");
@@ -155,7 +155,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testDelete() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testDelete() throws VetoException {
         final ActionWorkItemSetFieldCol52 column = new ActionWorkItemSetFieldCol52();
         column.setWorkItemName(WORK_ITEM_NAME);
         column.setHeader("col1");
@@ -176,7 +176,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testMoveColumnTo_MoveLeft() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveLeft() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -206,12 +206,12 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<Boolean>(true));
-        uiModel.setCell(0,
-                        5,
-                        new BaseGridCellValue<Boolean>(false));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Boolean>(true));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<Boolean>(false));
 
         assertEquals(3,
                      model.getActionCols().size());
@@ -278,7 +278,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testMoveColumnTo_MoveRight() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveRight() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -308,12 +308,12 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<Boolean>(true));
-        uiModel.setCell(0,
-                        5,
-                        new BaseGridCellValue<Boolean>(false));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Boolean>(true));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<Boolean>(false));
 
         assertEquals(3,
                      model.getActionCols().size());
@@ -380,7 +380,7 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
     }
 
     @Test
-    public void testMoveColumnTo_OutOfBounds() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_OutOfBounds() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -410,12 +410,12 @@ public class ActionWorkItemSetFieldColumnSynchronizerTest extends BaseSynchroniz
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<Boolean>(true));
-        uiModel.setCell(0,
-                        5,
-                        new BaseGridCellValue<Boolean>(false));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Boolean>(true));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<Boolean>(false));
 
         assertEquals(3,
                      model.getActionCols().size());
