@@ -16,7 +16,9 @@
 
 package org.drools.workbench.screens.guided.rule.client.editor.util;
 
+import java.util.Arrays;
 import java.util.List;
+import java.util.Objects;
 
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
 import org.drools.workbench.models.datamodel.rule.FactPattern;
@@ -107,7 +109,7 @@ public class ConstraintValueEditorHelper {
                                              if (lhsBoundField != null) {
                                                  final String boundClassName = oracle.getFieldClassName(lhsBoundField.getFactType(), lhsBoundField.getFieldName());
 
-                                                 if (getFieldTypeClazz().equals(boundClassName)) {
+                                                 if (Objects.equals(getFieldTypeClazz(), boundClassName)) {
                                                      callback.callback(true);
                                                      return;
                                                  }
@@ -219,8 +221,8 @@ public class ConstraintValueEditorHelper {
         String boundFieldType = this.model.getLHSBindingType(boundVariable);
 
         //If the fieldTypes are SuggestionCompletionEngine.TYPE_COMPARABLE check the enums are equivalent
-        if (boundFieldType.equals(DataType.TYPE_COMPARABLE)) {
-            if (!this.fieldType.equals(DataType.TYPE_COMPARABLE)) {
+        if (Objects.equals(boundFieldType, DataType.TYPE_COMPARABLE)) {
+            if (!Objects.equals(fieldType, DataType.TYPE_COMPARABLE)) {
                 callback.callback(false);
                 return;
             }
@@ -229,7 +231,7 @@ public class ConstraintValueEditorHelper {
             String parentFactTypeForBinding = this.model.getLHSParentFactPatternForBinding(boundVariable).getFactType();
             String[] dd = this.oracle.getEnumValues(parentFactTypeForBinding,
                                                     fieldName);
-            callback.callback(isEnumEquivalent(dd));
+            callback.callback(isEnumEquivalent(dd, dropDownData));
             return;
         }
 
@@ -237,25 +239,13 @@ public class ConstraintValueEditorHelper {
                                              callback);
     }
 
-    private boolean isEnumEquivalent(String[] values) {
-        if (values == null && this.dropDownData.getFixedList() == null) {
-            return true;
+    public static boolean isEnumEquivalent(final String[] values, final DropDownData dropDownData) {
+        if (dropDownData != null) {
+            return Arrays.equals(values, dropDownData.getFixedList());
+        } else {
+            // dropDownData is null, so check if also values are null
+            return values == null;
         }
-        if (values == null && this.dropDownData.getFixedList() != null) {
-            return false;
-        }
-        if (values != null && this.dropDownData.getFixedList() == null) {
-            return false;
-        }
-        if (values.length != this.dropDownData.getFixedList().length) {
-            return false;
-        }
-        for (int i = 0; i < values.length; i++) {
-            if (!values[i].equals(this.dropDownData.getFixedList()[i])) {
-                return false;
-            }
-        }
-        return true;
     }
 
     private void isLHSFactTypeEquivalent(final String boundVariable,
@@ -331,7 +321,7 @@ public class ConstraintValueEditorHelper {
             }
             String[] dd = oracle.getEnumValues(boundFactType,
                                                fieldName);
-            callback.callback(isEnumEquivalent(dd));
+            callback.callback(isEnumEquivalent(dd, dropDownData));
         } else {
 
             this.oracle.getSuperTypes(boundFactType, new Callback<List<String>>() {
@@ -352,7 +342,7 @@ public class ConstraintValueEditorHelper {
     private boolean checkSuperTypes(List<String> superTypes) {
         if (superTypes != null) {
             for (String superType : superTypes) {
-                if (getFieldTypeClazz().equals(superType)) {
+                if (Objects.equals(getFieldTypeClazz(), superType)) {
                     return true;
                 }
             }
